"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenshinUser = void 0;
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const base_1 = require("./base");
const validator_1 = require("../utils/validator");
class GenshinUser extends base_1.BaseRoute {
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = this.getFetchOptions(options);
        if (!(0, validator_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new request_1.request({
            withDS: true,
            withExtraHeaders: true,
        });
        instance.setLanguage(language);
        const res = await instance.get("index", {
            Cookie: cookie,
        }, {
            server: (0, getServer_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(uid, data);
        }
        return data;
    }
}
exports.GenshinUser = GenshinUser;
